#
# spec file for package plank
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define lname	libplank1
%define _version 1.0
Name:           plank
Version:        0.11.2
Release:        1.1
Summary:        Elegant, simple, and clean dock
License:        GPL-3.0+
Group:          System/GUI/Other
Url:            https://launchpad.net/plank
Source:         https://launchpad.net/%{name}/%{_version}/%{version}/+download/%{name}-%{version}.tar.xz
Source2:        https://launchpad.net/%{name}/%{_version}/%{version}/+download/%{name}-%{version}.tar.xz.asc
Source3:        %{name}.keyring
BuildRequires:  autoconf >= 2.65
BuildRequires:  automake >= 1.11
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  libtool >= 2
BuildRequires:  libxml2-tools
BuildRequires:  pkg-config >= 0.21
BuildRequires:  update-desktop-files
BuildRequires:  vala >= 0.28.0
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(dbusmenu-glib-0.4) >= 0.4
BuildRequires:  pkgconfig(dbusmenu-gtk3-0.4) >= 0.4
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.26.0
BuildRequires:  pkgconfig(gdk-x11-3.0) >= 3.10.0
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0) >= 2.40
BuildRequires:  pkgconfig(glib-2.0) >= 2.40
BuildRequires:  pkgconfig(gobject-2.0) >= 2.34
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.10.0
BuildRequires:  pkgconfig(libbamf3) >= 0.2.92
BuildRequires:  pkgconfig(libwnck-3.0)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xfixes) >= 5.0
BuildRequires:  pkgconfig(xi) >= 1.6.99.1
Requires:       bamf-daemon >= 0.2.92
Recommends:     %{name}-lang
%glib2_gsettings_schema_requires

%description
Plank is meant to be the simplest dock on the planet. The goal is
to provide just what a dock needs and absolutely nothing more.
It is, however, a library which can be extended to create other
dock programs with more advanced features.

%package -n %{lname}
Summary:        Library for the Plank dock
Group:          System/Libraries

%description -n %{lname}
Plank is meant to be the simplest dock on the planet. The goal is
to provide just what a dock needs and absolutely nothing more.
It is, however, a library which can be extended to create other
dock programs with more advanced features.

This package contains the plank library.

%package devel
Summary:        Development files for the Plank dock
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
The libxnoise development package includes the header files, libraries,
configuration files and development tools necessary for compiling and
linking application which will use libplank.

%lang_package

%prep
%setup -q

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
  --disable-static \
  --disable-apport
make %{?_smp_mflags}

%install
%make_install
%suse_update_desktop_file -r %{name} Utility DesktopUtility
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name}

%post
%icon_theme_cache_post
%desktop_database_post
%glib2_gsettings_schema_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%glib2_gsettings_schema_postun

%post -n %{lname} -p /sbin/ldconfig

%postun -n %{lname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS COPYING COPYRIGHT HACKING NEWS README
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_datadir}/glib-2.0/schemas/*%{name}.gschema.xml
%{_mandir}/man?/%{name}.?%{?ext_man}
%dir %{_datadir}/appdata
%{_datadir}/appdata/%{name}.appdata.xml

%files -n %{lname}
%defattr(-,root,root)
%{_libdir}/lib%{name}.so.*

%files lang -f %{name}.lang
%defattr(-,root,root)

%files devel
%defattr(-,root,root)
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/%{name}/
%{_libdir}/libplank.so
%{_datadir}/vala/

%changelog
* Sun Sep 18 2016 avvissu@yandex.by
- Update to 0.11.2:
  * Add support for HSL and some convenience functions
  * Fill in docklet descriptions
  * Add and enforce some file-count limits
  * Need to own clipboard's content before allowed to clear it
    (lp#1540081)
  * Pass correct index in menu-item-callback (lp#1577745)
  * Update translations
- Change in 0.11.1:
  * ApplicationDockItem: Use child-* signals of Bamf.View and force
    indicator-update if running-state changed
  * Actually emit DockController.elements_changed() to make
    DBusClient work
  * DockletManager: Only handle properly named docklet-libraries
  * Update translations
* Thu Mar 17 2016 sor.alexei@meowr.ru
- Update to 0.11.0:
  * Use non-linear transition in/out of the "zoom" state.
  * Add docklets support (Clippy, Clock, Desktop, Trash) (lp#731915).
  * Use GSettings for dock settings (themes and dockitem files
    remain at their location) (lp#994007).
  * Consolidate public API (breaks old themes and dockitem files,
    those are transitioned accordingly if possible).
  * Add "CascadeHide" theme option.
  * Don't grab input and abort this drag if DragItem is null
    (lp#1517897).
  * Add runtime support for gtk+ 3.19.1+ (lp#1523208).
  * Show descriptive tooltip for external-dnd actions (lp#1512998).
  * Update appdata to 0.6+ format.
  * Hide "Keep in Dock" wile LockItems is enabled (lp#1530963).
  * Don't apply window-scale-factor twice on foreground-icon-size.
  * Handle bad LauncherAPI clients which have an insane update-rate
    (lp#1514201).
  * Expose API to handle LauncherEntry D-Bus clients.
  * Expand dock on external-drag without enabled zoom too
    (lp#1007058).
  * Drop support for gee-1.0, having gee-0.8 is mandatory now.
  * Require glib >= 2.40 and gtk+ >= 3.10.
  * Handle file-monitor moved-event where launcher was target
    (lp#1522917).
  * Add "simple and experimental" multi-dock support.
  * Follow environment's setting whether to show notifications
    (lp#1523266).
  * Force SurfaceCache to allow downscale if drawing-time is
    insanely high (lp#1502429)
  * Add TooltipsEnabled setting (lp#1553246).
  * TOUCHPAD devices are able to perform pressure on a barrier too.
  * Some tweaking of the default themes.
  * Update translations.
* Sat Oct 10 2015 sor.alexei@meowr.ru
- Update to 0.10.1:
  * Require valac >= 0.24.0 as actually needed.
  * Correctly display filenames with underscores in folder-menu
    (lp#1501499).
  * plankdockitem: Open "preferences" on left-click instead of
    "about".
  * Properly determine drop-position of external drags with enabled
    icon-zoom.
  * Update translations.
- Generate icon cache after installation.
* Tue Sep  8 2015 sor.alexei@meowr.ru
- Update to 0.10.0:
  * Clean up and review appearances of DockItem in API an prefer
    DockElement.
  * Make the item for the dock-itself really special with its own
    setting.
  * Pass-through event on scroll/click to have a proper timestamps
    for WindowControl.* calls (lp#1167787, lp#1431556).
  * Handle invalid item on runtime (lp#1444830).
  * Fix LogLevel naming (Logger.FATAL -> Logger.ERROR,
    Logger.ERROR -> Logger.CRITICAL).
  * Make DockItem abstract.
  * Add frame_time to AnimatedRenderer with conditional use of
    GdkFrameClock (gtk+ >= 3.8).
  * Add RTL support (lp#1455892).
  * Add DODGE_ACTIVE hide-mode.
  * Conditional use of GtkStack instead of GtkNotebook in
    preferences-dialog (gtk+ >= 3.10).
  * Drop conditional dependency on gnome-common (and rely on
    autoconf-archive).
  * Add icon-zoom hover-effect (lp#707650).
  * Don't use pressure reveal for absolute input devices
    (lp#1349506).
  * Force indicating running applications (lp#1406282).
* Sat May  9 2015 jengelh@inai.de
- Add gpg signature; ensure dependencies from configure.ac
  are listed; set RPM groups
* Sat May  2 2015 sor.alexei@meowr.ru
- Update to 0.9.1:
  * Use selected-focused background-color from current gtk-theme.
  * Add FileDockItem.with_file() and expose OwnedFile.
  * plank.pc: Add pkgdatadir and missing dependency on libbamf3.
  * Add special theme "Gtk+" which looks in current gtk-theme.
  * Only show window-list and use "Close All" for more than one
    window.
  * lib: Handle DesktopAppInfo constructors returning NULL.
  * Don't hide while obstructed by one of our dialogs.
  * Fallback on "application-default-icon" only, otherwise use the
    internal default icon.
  * Do not allow multiple dockitems pointing to the same
    application/launcher.
  * Fix gee assert triggered in handle_name_owner_changed.
  * Require --enable-new-dtags support.
  * Update manpage.
  * Fix updating item-positions in panel-mode.
  * Accept all supported URIs.
  * Allow opening dropped files while LockItems is true.
  * Handle additional mouse-events for gtk+ 3.14+ to restore old
    behaviour while the dock-menu is shown.
  * Clean up and remove unused public API of position-manager.
  * Increase hover-window delay to 200ms.
  * Use ActionGroup/ActionMap capabilities to provide global-menu
    functions.
  * Port AbstractMain to inherit directly from Gtk.Application.
  * Add simple preferences dialog (hidden in Pantheon environments).
  * Fix some HiDPI issues.
  * Fix DockContainer destructor name (Fix build with valac
    0.27/git-master).
  * Make use of Gdk.EVENT_PROPAGATE and Gdk.EVENT_STOP.
  * Compatibility for BSD, use replacement for sys/prctl.h.
  * Request gee-0.8 without an automatic fallback to gee-1.0.
  * positionmanager: Alignment should have same meaning for dock
    and items START and END were treated differently resulting in
    a contradicting settings-behaviour of Aligment and
    ItemsAlignment.
  * Fix broken virtual LauncherEntry-items.
  * Fix menu-position with gtk+ 3.15+.
  * Fix enable/disable pressure-reveal on runtime.
  * Output information for more enabled features.
  * Fix some sensitivity assignments in preferences dialog.
  * Add standard set of easing-functions.
  * Animate addition and removal for items (increase ItemMoveTime
    of Default theme to 450ms).
  * Add "hide-delay" setting.
  * Add "window-dodge" hide-mode.
  * Add DBusManager to provide some remotely accessible actions.
  * Increase default ItemMoveTime to 450ms.
  * settings: Save display-plug-name as "Monitor" which dock should
    be shown on.
  * Refactor and split up draw_item(), draw final internal
    dock-buffer on window-context at (0,0).
  * Trap XErrors caused by Wnck/Cairo.
  * Optimize application-default-icon.svg and replace poof.png with
    newly created poof.svg.
  * Do not stop motion-events by default.
  * Add support for loading icons with "resource://"-uris.
  * Generally watch for changes of the "Launcher"-file.
  * Refactor dealing with monitor-/size-changes to catch
    races-conditions.
  * Reverse ordering of menu-items for top-docks.
  * Add support for coverage analysis using gcov and lcov.
  * Start to improve coverage of tests.
  * Various API changes and refactoring, see full Changelog for
    details.
  * Initialize i18n as suggested here,
    https://developer.gnome.org/glib/stable/glib-I18N.html#glib-I18N.description
  * Draw/unhide the dock on login when there are no windows.
  * Explictly request/specify the FileMonitor-type which is needed.
  * Don't apply addition-animation to all items on startup.
  * Update translations.
- Remove GPG signature for simplification.
- Remove dead plank-branding dependency.
- Change group to System/GUI/Other.
- Spec cleanup.
* Wed Dec 31 2014 mailaender@opensuse.org
- update to version 0.7.1
* Thu May 15 2014 jengelh@inai.de
- initial package (version 0.6.0) for build.opensuse.org
